/**
 * Creating a sidebar enables you to:
 - create an ordered group of docs
 - render a sidebar for each doc of that group
 - provide next/previous navigation

 The sidebars can be generated from the filesystem, or explicitly defined here.

 Create as many sidebars as you want.
 */

// @ts-check

/** @type {import('@docusaurus/plugin-content-docs').SidebarsConfig} */
const sidebars = {
  docs: [
    {
      type: "category",
      label: "Usage",

      items: [
        { type: "doc", id: "docs/usage/quick-start" },
        { type: "doc", id: "docs/usage/input-components" },
        { type: "doc", id: "docs/usage/typesafe-props" },
        { type: "doc", id: "docs/usage/error-handling" },
        { type: "doc", id: "docs/usage/complex-fields" },
        { type: "doc", id: "docs/usage/schema-collisions" },
        { type: "doc", id: "docs/usage/form-components" },
        { type: "doc", id: "docs/usage/custom-layouts" },
        { type: "doc", id: "docs/usage/default-values" },
        { type: "doc", id: "docs/usage/form-state" },
        { type: "doc", id: "docs/usage/labels-placeholders" },
        { type: "doc", id: "docs/usage/field-schema-info" },
      ],
    },
    {
      type: "category",
      label: "Example Components",
      items: [
        { type: "doc", id: "docs/example-inputs/text-field" },
        { type: "doc", id: "docs/example-inputs/number-field" },
        { type: "doc", id: "docs/example-inputs/select" },
        { type: "doc", id: "docs/example-inputs/checkbox" },
        { type: "doc", id: "docs/example-inputs/multi-checkbox" },
      ],
    },
    {
      type: "doc",
      id: "docs/recommended-setup-tips",
    },
    {
      type: "doc",
      id: "docs/zod-tips",
    },
    {
      type: "doc",
      id: "docs/react-native",
    },
    {
      type: "doc",
      id: "docs/codesandbox-starter",
    },
  ],
  //api: [{ type: "autogenerated", dirName: "./api" }],
  api: [
    {
      type: "autogenerated",
      dirName: "api",
    },
  ],

  // But you can create a sidebar manually
  /*
  tutorialSidebar: [
    'intro',
    'hello',
    {
      type: 'category',
      label: 'Tutorial',
      items: ['tutorial-basics/create-a-document'],
    },
  ],
   */
};

module.exports = sidebars;
